@@ -1434,7 +1434,7 @@ bool KBgBoard::moveOffPossible() const
 KBgBoardCell* KBgBoard::getCellByPos(const TQPoint& p) const
 {
        	for (int i = 0; i < 30; ++i) {
-		if (TQT_TQRECT_OBJECT(cells[i]->rect()).contains(cells[i]->mapFromParent(p)))
+		if (cells[i]->rect().contains(cells[i]->mapFromParent(p)))
 			return cells[i];
 	}
 	return NULL;
