@@ -51,7 +51,7 @@ LinesBoard::LinesBoard( BallPainter * abPainter, TQWidget* parent, const char* n
 
   bPainter = abPainter;
 
-  setFocusPolicy( TQ_NoFocus );
+  setFocusPolicy( TQWidget::NoFocus );
   setBackgroundColor( gray );
 
   setMouseTracking( FALSE );
