@@ -61,7 +61,7 @@ Editor::Editor
     drawFrame->setGeometry( 10, 40 ,sWidth ,sHeight);
     drawFrame->setMinimumSize( 0, 0 );
     drawFrame->setMaximumSize( 32767, 32767 );
-    drawFrame->setFocusPolicy( TQ_NoFocus );
+    drawFrame->setFocusPolicy( TQWidget::NoFocus );
     drawFrame->setBackgroundMode( TQWidget::PaletteBackground );
     drawFrame->setFrameStyle( 49 );
     drawFrame->setMouseTracking(true);
