@@ -74,7 +74,7 @@ Status::Status(TQWidget *parent)
 	// smiley
 	smiley = new Smiley(this);
 	connect(smiley, TQT_SIGNAL(clicked()), TQT_SLOT(smileyClicked()));
-	smiley->setFocusPolicy(TQ_NoFocus);
+	smiley->setFocusPolicy(TQWidget::NoFocus);
 	TQWhatsThis::add(smiley, i18n("Press to start a new game"));
     top->addWidget(smiley, 0, 2);
 
