@@ -82,7 +82,7 @@ GameBoard::GameBoard( TQWidget *parent )
     setMinimumSize( 600, 600 );
 
     setMouseTracking( true );
-    setFocusPolicy( TQ_StrongFocus );
+    setFocusPolicy( TQWidget::StrongFocus );
     setFocus();
 
     //********************************************************************
