@@ -57,7 +57,7 @@ class QReversiGame;
 
 class StatusWidget : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
@@ -77,7 +77,7 @@ private:
 // The main game view
 
 class QReversiGameView : public TQWidget {
-  Q_OBJECT
+  TQ_OBJECT
   
 
 public:
